@@ -123,14 +123,13 @@ void gfx_dumpflags(Uint32 flags)
   sprintf(buf, "0x%8.8x", flags);
 
   strcat(buf, " ");
-  int i = 0;
-  for (; i < 32; i++)
+  char c[2] = "x";
+  int i = 32-1;
+  for (; i >= 0; i--)
     {
-      unsigned int tflag = 1 << i;
-      if ((flags & tflag) == tflag)
-	strcat(buf, "1");
-      else
-	strcat(buf, "0");
+      unsigned int b = flags >> i;
+      c[0] = '0' + (b & 0x1);
+      strcat(buf, c);
     }
 
   if (flags & SDL_HWSURFACE)
@@ -488,16 +487,22 @@ static SDL_Surface* load_bmp_internal(char *filename, SDL_RWops *rw, int from_me
       /* converted = SDL_ConvertSurface(image, image->format, image->flags); */
       SDL_Surface *converted = SDL_DisplayFormat(image);
 
-      /* In the end, the image must use the reference palette: that
-	 way no mistaken color conversion will occur during blits to
-	 other surfaces/buffers.  Blits should also be faster(?).
-	 Alternatively we could replace SDL_BlitSurface with a wrapper
-	 that sets identical palettes before the blits. */
-      SDL_SetPalette(converted, SDL_LOGPAL, GFX_real_pal, 0, 256);
-      
-      /* Blit the copy back to the original, with a potentially different
-	 palette, which triggers color conversion to image's palette. */
-      SDL_BlitSurface(image, NULL, converted, NULL);
+      /* TODO: the following is probably unnecessary, I think that's
+	 exactly what SDL_DisplayFormat does: convert the surface to
+	 the screen's logical palette. Cf. test/sdl/paltest.c. */
+      {
+	/* In the end, the image must use the reference palette: that
+	   way no mistaken color conversion will occur during blits to
+	   other surfaces/buffers.  Blits should also be faster(?).
+	   Alternatively we could replace SDL_BlitSurface with a
+	   wrapper that sets identical palettes before the blits. */
+	SDL_SetPalette(converted, SDL_LOGPAL, GFX_real_pal, 0, 256);
+	
+	/* Blit the copy back to the original, with a potentially
+	   different palette, which triggers color conversion to
+	   image's palette. */
+	SDL_BlitSurface(image, NULL, converted, NULL);
+      }
       SDL_FreeSurface(image);
       image = NULL;
 
@@ -546,9 +551,14 @@ int gfx_blit_nocolorkey(SDL_Surface *src, SDL_Rect *src_rect,
 
   Uint32 colorkey_flags, colorkey, alpha_flags, alpha;
   colorkey_flags = src->flags & (SDL_SRCCOLORKEY|SDL_RLEACCEL);
+#if SDL_VERSION_ATLEAST(1, 3, 0)
+  SDL_GetColorKey(src, &colorkey);
+  /* 1.3 TODO: alpha */
+#else
   colorkey = src->format->colorkey;
   alpha_flags = src->flags & (SDL_SRCALPHA|SDL_RLEACCEL);
   alpha = src->format->alpha;
+#endif
   SDL_SetColorKey(src, 0, -1);
   SDL_SetAlpha(src, 0, -1);
   
@@ -590,7 +600,13 @@ int gfx_blit_stretch(SDL_Surface *src_surf, SDL_Rect *src_rect,
 	 non-transparent surfaces) */
       int colorkey_flag = src_surf->flags & SDL_SRCCOLORKEY;
       Uint8 r, g, b, a;
-      SDL_GetRGBA(src_surf->format->colorkey, src_surf->format, &r, &g, &b, &a);
+#if SDL_VERSION_ATLEAST(1, 3, 0)
+      Uint32 colorkey;
+      SDL_GetColorKey(src_surf, &colorkey);
+# else
+      Uint32 colorkey = src_surf->format->colorkey;
+#endif
+      SDL_GetRGBA(colorkey, src_surf->format, &r, &g, &b, &a);
 
       SDL_SetColorKey(scaled, colorkey_flag,
 		      SDL_MapRGBA(scaled->format, r, g, b, a));
