@@ -1,7 +1,7 @@
 /**
  * Translate game texts
 
- * Copyright (C) 2008  Sylvain Beucler
+ * Copyright (C) 2008, 2009  Sylvain Beucler
 
  * This file is part of GNU FreeDink
 
@@ -23,6 +23,6 @@
 #ifndef _I18N_H
 #define _I18N_H
 
-  extern void i18n_translate(char* text, int buf_size);
+extern char* i18n_translate(char* scriptname, int line, char* text);
 
 #endif
