@@ -1,7 +1,7 @@
 /**
  * Compute and store the search paths
 
- * Copyright (C) 2007  Sylvain Beucler
+ * Copyright (C) 2007, 2008, 2009  Sylvain Beucler
 
  * This file is part of GNU FreeDink
 
@@ -37,13 +37,20 @@ extern "C"
   extern const char *paths_getdefaultpkgdatadir(void);
   extern const char *paths_getpkgdatadir(void);
   extern const char *paths_getexedir(void);
+  extern const char *paths_getexefile(void);
+
   extern char* paths_dmodfile(char* file);
   extern char* paths_fallbackfile(char* file);
+  extern char* paths_defaultpkgdatafile(char* file);
   extern char* paths_pkgdatafile(char* file);
+  extern char* paths_exedirfile(char* file);
+
   extern FILE* paths_dmodfile_fopen(char* file, char* mode);
   extern FILE* paths_fallbackfile_fopen(char* file, char* mode);
   extern FILE* paths_defaultpkgdatafile_fopen(char* file, char* mode);
   extern FILE* paths_pkgdatafile_fopen(char* file, char* mode);
+  extern FILE* paths_exedirfile_fopen(char* file, char* mode);
+
   extern FILE* paths_savegame_fopen(int num, char* mode);
   extern void paths_quit(void);
 
