@@ -3,7 +3,7 @@
 
  * Copyright (C) 1997, 1998, 1999, 2002, 2003  Seth A. Robinson
  * Copyright (C) 2003  Shawn Betts
- * Copyright (C) 2005, 2007  Sylvain Beucler
+ * Copyright (C) 2005, 2007, 2008, 2009  Sylvain Beucler
 
  * This file is part of GNU FreeDink
 
@@ -22,6 +22,14 @@
  * <http://www.gnu.org/licenses/>.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include <stdlib.h>
+#include <string.h>  /* memset, memcpy */
+#include <errno.h>
+
 #include "SDL.h"
 #include "SDL_mixer.h"
 #include "game_engine.h"
@@ -30,6 +38,7 @@
 #include "log.h"
 #include "math.h"
 #include "sfx.h"
+#include "log.h"
 
 
 /* Channel metadata */
@@ -40,7 +49,8 @@ struct
   int owner;
   int survive;
   int cur_sound; /* Sound currently played in that channel */
-  Uint8 *fake_buf;
+  int looping;
+  int finished;
 } channelinfo[NUM_CHANNELS];
 
 
@@ -53,6 +63,7 @@ static struct
   int pos_lastframe; /* index for the last frame */
   int pos_end; /* upper bound (pre-calculated for efficiency&simplicity) */
   SDL_AudioCVT cvt;
+  Uint32 cvt_buf_len;
 } registered_sounds[MAX_SOUNDS];
 
 
@@ -60,6 +71,9 @@ static struct
 static int hw_freq, hw_channels;
 static Uint16 hw_format;
 
+/* Fake buffer */
+static Uint8* fake_buf = NULL;
+static Uint32 fake_buf_len = 0;
 
 static int SetVolume(int channel, int dx_volume);
 static int SetPan(int channel, int dx_panning);
@@ -103,6 +117,7 @@ struct callback_data
   int pos; /* which sample (not frame) we're playing now, in 1/256th */
   int shift; /* position advance for 1 frame, in 1/256th */
   int sound; /* sound index */
+  int channel; /* channel index */
 };
 static void callback_samplerate_cleanup(int chan, void *udata)
 {
@@ -111,6 +126,8 @@ static void callback_samplerate_cleanup(int chan, void *udata)
 static void callback_samplerate(int chan, void *stream, int len, void *udata)
 {
   struct callback_data* data = (struct callback_data*)udata;
+  if (channelinfo[data->channel].finished == 1)
+    return;
 
   /* printf("%d - %d/%d\n", len, data->pos>>8, registered_sounds[data->sound].pos_end>>8); */
   int pos_end = registered_sounds[data->sound].pos_end;
@@ -148,7 +165,14 @@ static void callback_samplerate(int chan, void *stream, int len, void *udata)
 	      
 	      data->pos += data->shift;
 	      if (data->pos >= pos_end)
-		data->pos = 0;
+		{
+		  if (!channelinfo[data->channel].looping)
+		    {
+		      channelinfo[data->channel].finished = 1;
+		      break;
+		    }
+		  data->pos = 0;
+		}
 	    }
  	}
       else if (hw_channels == 2)
@@ -188,7 +212,14 @@ static void callback_samplerate(int chan, void *stream, int len, void *udata)
 	      
 	      data->pos += data->shift;
 	      if (data->pos >= pos_end)
-		data->pos = 0;
+		{
+		  if (!channelinfo[data->channel].looping)
+		    {
+		      channelinfo[data->channel].finished = 1;
+		      break;
+		    }
+		  data->pos = 0;
+		}
 	    }
 	}
       break;
@@ -222,7 +253,14 @@ static void callback_samplerate(int chan, void *stream, int len, void *udata)
 	      
 	      data->pos += data->shift;
 	      if (data->pos >= pos_end)
-		data->pos = 0;
+		{
+		  if (!channelinfo[data->channel].looping)
+		    {
+		      channelinfo[data->channel].finished = 1;
+		      break;
+		    }
+		  data->pos = 0;
+		}
 	    }
 	}
       else if (hw_channels == 2)
@@ -262,13 +300,32 @@ static void callback_samplerate(int chan, void *stream, int len, void *udata)
 	      
 	      data->pos += data->shift;
 	      if (data->pos >= pos_end)
-		data->pos = 0;
+		{
+		  if (!channelinfo[data->channel].looping)
+		    {
+		      channelinfo[data->channel].finished = 1;
+		      break;
+		    }
+		  data->pos = 0;
+		}
 	    }
 	}
       break;
     }
 }
 
+/**
+ * Close channels that stopped playing
+ */
+void sfx_cleanup_finished_channels()
+{
+  int i = 0;
+  for (i = 0; i < NUM_CHANNELS; i++)
+    {
+      if (channelinfo[i].finished == 1)
+	Mix_HaltChannel(i);
+    }
+}
 
 
 
@@ -289,7 +346,7 @@ int CreateBufferFromWaveFile(char* filename, int index)
     in = paths_fallbackfile_fopen(path, "rb");
   if (in == NULL)
     {
-      perror("CreateBufferFromWaveFile");
+      log_debug("CreateBufferFromWaveFile: %s", strerror(errno));
       return 0;
     }
 
@@ -305,7 +362,7 @@ int CreateBufferFromWaveFile_RW(SDL_RWops* rwops, int rwfreesrc, int index)
   // Safety check
   if (index >= MAX_SOUNDS)
     {
-      fprintf(stderr, "SCRIPTING ERROR: sound index %d is too big.\n", index);
+      log_error("SCRIPTING ERROR: sound index %d is too big.", index);
       return 0;
     }
 
@@ -315,12 +372,12 @@ int CreateBufferFromWaveFile_RW(SDL_RWops* rwops, int rwfreesrc, int index)
 
   if (SDL_LoadWAV_RW(rwops, rwfreesrc, &wav_spec, &wav_buf, &wav_len) == NULL)
     {
-      fprintf(stderr, "Could not open sound file: %s\n", SDL_GetError());
+      log_error("Could not open sound file: %s", SDL_GetError());
       return 0;
     }
-  printf("info: frequency=%dHz\tformat=%s\tchannels=%d\tlength=%d bytes\n",
-	 wav_spec.freq, format2string(wav_spec.format),
-	 wav_spec.channels, wav_len);
+  log_info("frequency=%dHz\tformat=%s\tchannels=%d\tlength=%d bytes",
+	   wav_spec.freq, format2string(wav_spec.format),
+	   wav_spec.channels, wav_len);
 
 
   /* Converting some WAV data to hardware format - except for sample
@@ -339,12 +396,13 @@ int CreateBufferFromWaveFile_RW(SDL_RWops* rwops, int rwfreesrc, int index)
   
   /* Check that the convert was built */
   if (ret == -1) {
-    fprintf(stderr, "Couldn't build converter: %s\n", SDL_GetError());
+    log_error("Couldn't build converter: %s", SDL_GetError());
     SDL_FreeWAV(wav_buf);
   }
 
   /* Setup for conversion */
-  cvt.buf = (Uint8 *)malloc(wav_len*cvt.len_mult);
+  Uint32 cvt_buf_len = wav_len*cvt.len_mult;
+  cvt.buf = (Uint8 *)malloc(cvt_buf_len);
   cvt.len = wav_len;
   memcpy(cvt.buf, wav_buf, wav_len);
   
@@ -355,7 +413,7 @@ int CreateBufferFromWaveFile_RW(SDL_RWops* rwops, int rwfreesrc, int index)
   /* And now we're ready to convert */
   ret = SDL_ConvertAudio(&cvt);
   if (ret == -1) {
-    fprintf(stderr, "Couldn't convert audiox: %s\n", SDL_GetError());
+    log_error("Couldn't convert audiox: %s", SDL_GetError());
     SDL_FreeWAV(wav_buf);
   }
   
@@ -376,6 +434,7 @@ int CreateBufferFromWaveFile_RW(SDL_RWops* rwops, int rwfreesrc, int index)
   registered_sounds[index].orig_spec = wav_spec;
   registered_sounds[index].orig_len = wav_len;
   registered_sounds[index].cvt = cvt;
+  registered_sounds[index].cvt_buf_len = cvt_buf_len;
   registered_sounds[index].pos_end = pos_end;
   registered_sounds[index].pos_lastframe = pos_lastframe;
   
@@ -406,8 +465,8 @@ int playing(int sound)
 {
   if (sound >= MAX_SOUNDS)
     {
-      Msg("Attempting to get the status of sound %d (> MAX_SOUNDS=%d)",
-          sound, MAX_SOUNDS);
+      log_error("Attempting to get the status of sound %d (> MAX_SOUNDS=%d)",
+		sound, MAX_SOUNDS);
       return 0;
     }
 
@@ -424,7 +483,7 @@ void kill_repeat_sounds(void)
   if (!sound_on)
     return;
   
-  Msg("Killing repeating sound");
+  log_info("Killing repeating sound");
 
   for (i = 0; i < NUM_CHANNELS; i++)
     {
@@ -434,7 +493,7 @@ void kill_repeat_sounds(void)
           && (channelinfo[i].survive == 0))
         {
           Mix_HaltChannel(i);
-	  Msg("Killed repeating sound %d", i);
+	  log_info("Killed repeating sound %d", i);
           channelinfo[i].repeat = 0;
         }
     }
@@ -563,7 +622,7 @@ static int SoundPlayEffectChannel(int sound, int min, int plus, int sound3d, /*b
   // Safety check
   if (registered_sounds[sound].cvt.buf == NULL)
     {
-      fprintf(stderr, "Error: attempting to play empty sound %d.\n", sound);
+      log_warn("Attempting to play empty sound %d.", sound);
       return 0;
     }
 
@@ -585,42 +644,34 @@ static int SoundPlayEffectChannel(int sound, int min, int plus, int sound3d, /*b
        play one frame with hw_freq */
     int shift = ((int)round((double)play_freq / hw_freq * (1<<8)));
     /* printf("shift=%d (%d*64)\n", shift, shift>>8); */
-    
-    /** Create a junk wav of the right size **/
-    int resized_len = registered_sounds[sound].cvt.len_cvt * ((double)hw_freq / play_freq);
 
-    /* Fake buffer: we give an empty buffer to SDL_mixer and a size
-       information that matches the sound sample with the target
-       sample rate, so the mixer will play and stop the sound
-       appropriately. We won't actually play from that buffer though,
-       as the audio buffer will be generated in
-       callback_samplerate(). */
-    /* We used to share the buffer among channels, but it made the
-       engine crash if the buffer was realloc()'d to store a bigger
-       sound _and_ moved to a different memory address in the process
-       (while other existing sounds would still refer to the old,
-       freed memory location). */
-    Uint8* fake_buf = NULL;
-    fake_buf = malloc(resized_len);
-    Mix_Chunk *chunk = Mix_QuickLoad_RAW(fake_buf, resized_len);
-    /* printf("resized_len=%d bytes, pos_end=%d\n", resized_len, pos_end); */
+    /* Fake buffer: we give an empty buffer to SDL_mixer. We won't
+       actually play from that buffer though, as the audio buffer will
+       be generated in callback_samplerate(). That function will also
+       take care of updating the channelinfo when it's finished (and
+       should be cleaned from a non-callback function). */
+    Mix_Chunk *chunk = Mix_QuickLoad_RAW(fake_buf, fake_buf_len);
     
-    channel = Mix_PlayChannel(explicit_channel, chunk, repeat ? -1 : 0);
+    channel = Mix_PlayChannel(explicit_channel, chunk, -1);
     if (channel < 0)
       {
-	fprintf(stderr, "Mix_PlayChannel: Error playing sound %d - %s\n",
-		sound, Mix_GetError());
+	log_error("Mix_PlayChannel: Error playing sound %d - %s",
+		  sound, Mix_GetError());
 	return 0;
       }
-    channelinfo[channel].fake_buf = fake_buf;
+    Mix_Pause(channel);
+    channelinfo[channel].finished = 0;
+    channelinfo[channel].looping = repeat;
 
     struct callback_data *data = calloc(1, sizeof(struct callback_data));
     data->pos = 0;
     data->shift = shift;
     data->sound = sound;
+    data->channel = channel;
 
     Mix_RegisterEffect(channel, callback_samplerate, callback_samplerate_cleanup, data);
     Mix_ChannelFinished(CleanupChannel);
+    Mix_Resume(channel);
   }
 
 
@@ -652,8 +703,8 @@ int SoundStopEffect(int sound)
 
   if (sound >= MAX_SOUNDS)
     {
-      fprintf(stderr, "Attempting to get stop sound %d (> MAX_SOUNDS=%d)",
-	      sound, MAX_SOUNDS);
+      log_error("Attempting to get stop sound %d (> MAX_SOUNDS=%d)",
+		sound, MAX_SOUNDS);
       return 0;
     }
 
@@ -673,11 +724,11 @@ int SoundStopEffect(int sound)
  */
 int InitSound()
 {
-  Msg("initting sound");
+  log_info("initting sound");
 
   if (SDL_Init(SDL_INIT_AUDIO) == -1)
     {
-      Msg("SDL_Init: %s\n", SDL_GetError());
+      log_error("SDL_Init(SDL_INIT_AUDIO): %s", SDL_GetError());
       return -1;
     }
   
@@ -688,9 +739,10 @@ int InitSound()
   /* MIX_DEFAULT_CHANNELS is 2 => stereo, allowing panning effects */
   /* 1024 (chunk on which effects are applied) seems a good default,
      4096 is considered too big for SFX */
-  if (Mix_OpenAudio(MIX_DEFAULT_FREQUENCY, MIX_DEFAULT_FORMAT, MIX_DEFAULT_CHANNELS, 1024) == -1)
+  int buf_samples = 1024;
+  if (Mix_OpenAudio(MIX_DEFAULT_FREQUENCY, MIX_DEFAULT_FORMAT, MIX_DEFAULT_CHANNELS, buf_samples) == -1)
     {
-      Msg("Mix_OpenAudio: %s", Mix_GetError());
+      log_error("Mix_OpenAudio: %s", Mix_GetError());
       return -1;
     }
 
@@ -707,17 +759,29 @@ int InitSound()
     int numtimesopened;
     numtimesopened = Mix_QuerySpec(&hw_freq, &hw_format, &hw_channels);
     if (!numtimesopened)
-      printf("Mix_QuerySpec: %s\n", Mix_GetError());
+      log_error("Mix_QuerySpec: %s", Mix_GetError());
     else
-      printf("Audio hardware info: frequency=%dHz\tformat=%s\tchannels=%d\topened=%d times\n",
-	     hw_freq, format2string(hw_format), hw_channels, numtimesopened);
+      log_info("Audio hardware info: frequency=%dHz\tformat=%s\tchannels=%d\topened=%d times",
+	       hw_freq, format2string(hw_format), hw_channels, numtimesopened);
   }
 
+  /* Allocate fake buffer - use the same size as the audio buffer */
+  fake_buf_len = buf_samples;
+  fake_buf_len *= hw_channels;
+  if (hw_format != AUDIO_U8 && hw_format != AUDIO_S8)
+    /*  2 bytes per frame */
+    fake_buf_len *= 2;
+  fake_buf = calloc(1, fake_buf_len);
+
   /* No sound playing yet - initialize the lookup table: */
   memset(channelinfo, 0, sizeof(channelinfo));
   int i;
   for (i = 0; i < NUM_CHANNELS; i++)
-    channelinfo[i].cur_sound = -1;
+    {
+      channelinfo[i].cur_sound = -1;
+      channelinfo[i].finished = 0;
+      channelinfo[i].looping = 0;
+    }
 
   /* No sound loaded yet - initialise the registered sounds: */
   memset(registered_sounds, 0, sizeof(registered_sounds));
@@ -733,21 +797,43 @@ int InitSound()
  */
 void QuitSound(void)
 {
-  int idxKill;
-  
+  if (SDL_WasInit(SDL_INIT_AUDIO) == 0)
+    return;
+
   /* Stops all SFX channels */
   Mix_HaltChannel(-1);
   
   /**
    * Frees up resources associated with a sound effect
    */
-  for (idxKill = 0; idxKill < MAX_SOUNDS; idxKill++)
+  int idxKill = 0;  
+  for (; idxKill < MAX_SOUNDS; idxKill++)
     FreeRegisteredSound(idxKill);
 
+  free(fake_buf);
+
   Mix_CloseAudio();
   SDL_QuitSubSystem(SDL_INIT_AUDIO);
 }
 
+/**
+ * Print SFX memory usage
+ */
+void sfx_log_meminfo()
+{
+  int sum = 0;
+  int i = 0;
+
+  sum = 0;
+  for (i = 0; i < MAX_SOUNDS; i++)
+    {
+      if (registered_sounds[i].cvt.buf != NULL)
+	sum += registered_sounds[i].cvt_buf_len;
+    }
+  log_debug("Sounds   = %8d", sum);
+}
+
+
 /**
  * Free memory used by sound #'sound'
  */
@@ -777,13 +863,12 @@ static void CleanupChannel(int channel)
   Mix_Chunk *chunk = Mix_GetChunk(channel);
   if (chunk == NULL)
     {
-      printf("Internal error: cannot free channel %d's chunk (where did it disappear?)\n", channel);
+      log_fatal("Internal error: cannot free channel %d's chunk (where did it disappear?)", channel);
       exit(1);
     }
   Mix_FreeChunk(chunk);
-  /* WAV buffer is not freed when Chunk is created using
-     Mix_QuickLoad_RAW (cf. chunk->allocated), do it manually. */
-  free(channelinfo[channel].fake_buf);
+  channelinfo[channel].finished = 0;
+  channelinfo[channel].looping = 0;
   channelinfo[channel].cur_sound = -1;
 
   /* Revert SetVolume and SetPan effects */
