@@ -3,7 +3,7 @@
 
  * Copyright (C) 1997, 1998, 1999, 2002, 2003  Seth A. Robinson
  * Copyright (C) 2005, 2006  Dan Walma
- * Copyright (C) 2005, 2007, 2008, 2009, 2010  Sylvain Beucler
+ * Copyright (C) 2005, 2007, 2008, 2009, 2010, 2011  Sylvain Beucler
 
  * This file is part of GNU FreeDink
 
@@ -49,6 +49,7 @@
 #include "rect.h"
 #include "dinkc_console.h"
 #include "input.h"
+#include "sfx.h"
 
 #include "update_frame.h"
 
@@ -71,7 +72,6 @@ void updateFrame( void )
     }
   frames++;
   
-    unsigned char state[256]; 
 /*     RECT                box_crap,box_real; */
     SDL_Rect GFX_box_crap;
 
@@ -247,8 +247,6 @@ trigger_start:
 	
 	
 	
-	state[1] = 0;  
-	
 	//figure out frame rate
 	drawthistime = /*true*/1;
 	
